==> senior_design_system-0.21.4.tar.gz: example/lib/pages/menu_list_item_example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class MenuListItemExample extends StatefulWidget {
  const MenuListItemExample({Key? key}) : super(key: key);

  @override
  _MenuListItemExampleState createState() => _MenuListItemExampleState();
}

class _MenuListItemExampleState extends State<MenuListItemExample> {
  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Menu List Item',
      child: ListView(
        children: [
          SeniorMenuItemList(
            title: '+55 47 9 0000-0000',
            subtitle: 'Pessoal',
            iconData: FontAwesomeIcons.phoneSquareAlt,
            leftPadding: 16,
            rightPadding: 16,
          ),
          SeniorMenuItemList(
            title: '+55 47 9 0000-0000',
            subtitle: 'Profissional',
            iconData: FontAwesomeIcons.phoneSquareAlt,
          ),
          SeniorMenuItemList(
            title: '+55 47 9 0000-0000',
            subtitle: 'Outro',
          ),
          SeniorMenuItemList(
            title: 'nome.colaborador@pessoal.com.br',
            subtitle: 'Pessoal',
            iconData: FontAwesomeIcons.solidEnvelope,
          ),
          SeniorMenuItemList(
            title: 'nome.colaborador@empresa.com.br',
            subtitle: 'Profissional',
            iconData: FontAwesomeIcons.solidEnvelope,
          ),
          SeniorMenuItemList(
            title: 'Resumo profissional',
            iconData: FontAwesomeIcons.solidUser,
            onTap: () {},
          ),
          SeniorMenuItemList(
            title: 'Contatos de emergência com texto grande para ver se vai quebrar',
            iconData: FontAwesomeIcons.solidUser,
            onTap: () {},
            enabled: true,
            leftPadding: 16,
            rightPadding: 16,
          ),
          SeniorMenuItemList(
            title: 'Documentos pessoais',
            iconData: FontAwesomeIcons.solidUser,
            onTap: () {},
            enabled: false,
          ),
        ],
      ),
    );
  }
}

==> senior_design_system-6.0.0.tar.gz: example/lib/pages/menu_list_item_example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class MenuListItemExample extends StatefulWidget {
  const MenuListItemExample({Key? key}) : super(key: key);

  @override
  _MenuListItemExampleState createState() => _MenuListItemExampleState();
}

class _MenuListItemExampleState extends State<MenuListItemExample> {
  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Menu List Item',
      child: ListView(
        children: [
          const SeniorMenuItemList(
            title: '+55 47 9 0000-0000',
            subtitle: 'Pessoal',
            iconData: FontAwesomeIcons.squarePhoneFlip,
            leftPadding: 16,
            rightPadding: 16,
          ),
          const SeniorMenuItemList(
            title: '+55 47 9 0000-0000',
            subtitle: 'Profissional',
            iconData: FontAwesomeIcons.squarePhoneFlip,
          ),
          const SeniorMenuItemList(
            title: '+55 47 9 0000-0000',
            subtitle: 'Outro',
          ),
          const SeniorMenuItemList(
            title: 'nome.colaborador@pessoal.com.br',
            subtitle: 'Pessoal',
            iconData: FontAwesomeIcons.solidEnvelope,
          ),
          const SeniorMenuItemList(
            title: 'nome.colaborador@empresa.com.br',
            subtitle: 'Profissional',
            iconData: FontAwesomeIcons.solidEnvelope,
          ),
          SeniorMenuItemList(
            title: 'Resumo profissional',
            iconData: FontAwesomeIcons.solidUser,
            onTap: () {},
          ),
          SeniorMenuItemList(
            title:
                'Contatos de emergência com texto grande para ver se vai quebrar',
            iconData: FontAwesomeIcons.solidUser,
            onTap: () {},
            enabled: true,
            leftPadding: 16,
            rightPadding: 16,
          ),
          SeniorMenuItemList(
            title: 'Documentos pessoais',
            iconData: FontAwesomeIcons.solidUser,
            onTap: () {},
            enabled: false,
          ),
        ],
      ),
    );
  }
}
